==> csmlog-0.3a0.tar.gz: csmlog-0.3a0/csmlog/__init__.py <==
'''
This file is part of csmlog. Python logger setup... the way I like it.
MIT License (2019) - Charles Machalow
'''

import logging
import logging.handlers
import os
import shutil

__version__ = '0.3a'

class CSMLogger(object):
    '''
    object to wrap logging logic
    '''
    theLogger = None # class-obj for the used logger

    def __init__(self, appName, clearLogs=False):
        self.appName = appName
        if clearLogs:
            self.clearLogs()

        self.parentLogger = self.__getParentLogger()
        self._loggers = [self.parentLogger] # keep track of all loggers

    def close(self):
        for logger in self._loggers:
            for handler in logger.handlers[:]:
                handler.close()
                logger.removeHandler(handler)

        self._loggers = []

    def getLogger(self, name):
        loggerName = '%s.%s' % (self.appName, name) # make this a sublogger of the whole app
        logger = self.__getLoggerWithName(loggerName)
        self._loggers.append(logger)
        return logger

    def __getParentLogger(self):
        return self.__getLoggerWithName(self.appName)

    def __getLoggerWithName(self, loggerName):
        logger = logging.getLogger(loggerName)
        logger.setLevel(1) # log all

        logFolder = self.getDefaultSaveDirectory()

        logFile = os.path.join(logFolder, loggerName + ".txt")

        formatter = logging.Formatter('%(asctime)s - %(name)s:%(lineno)d - %(levelname)s - %(message)s')

        rfh = logging.handlers.RotatingFileHandler(logFile, maxBytes=1024*1024*8, backupCount=10)
        rfh.setFormatter(formatter)
        logger.addHandler(rfh)

        return logger

    def getDefaultSaveDirectory(self):
        return self.getDefaultSaveDirectoryWithName(self.appName)

    @classmethod
    def getDefaultSaveDirectoryWithName(cls, appName):
        if os.name == 'nt':
            logFolder = os.path.join(os.path.expandvars("%APPDATA%"), appName)
        else:
            logFolder = os.path.join('/var/log/', appName)

        if not os.path.isdir(logFolder):
            os.makedirs(logFolder)

        return logFolder

    def clearLogs(self):
        shutil.rmtree(self.getDefaultSaveDirectory())

        # recreate empty folder
        self.getDefaultSaveDirectory()

    @classmethod
    def setup(cls, appName, clearLogs=False):
        ''' must be called to setup the logger. Passes args to CSMLogger's constructor '''
        if getattr(cls, 'theLogger', None):
            raise RuntimeError("CSMLogger was already setup. It can only be setup once!")

        CSMLogger.theLogger = CSMLogger(appName, clearLogs)
        CSMLogger.theLogger.parentLogger.debug("==== %s is starting ====" % appName)


# the following helper logic only works if the entire application is for one logging folder.
#  not quite sure if it would work with multiple CSMLoggers with different app names

def getLogger(*args, **kwargs):
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")

    return CSMLogger.theLogger.getLogger(*args, **kwargs)

def close():
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")
    retVal = CSMLogger.theLogger.close()
    CSMLogger.theLogger = None
    return retVal

def getCSMLogger():
    return CSMLogger.theLogger

setup = CSMLogger.setup

==> csmlog-0.4a0.tar.gz: csmlog-0.4a0/csmlog/__init__.py <==
'''
This file is part of csmlog. Python logger setup... the way I like it.
MIT License (2019) - Charles Machalow
'''

import logging
import logging.handlers
import os
import shutil
import sys

__version__ = '0.4a'

from csmlog.udp_handler import UdpHandler
from csmlog.udp_handler_receiver import UdpHandlerReceiver

class CSMLogger(object):
    '''
    object to wrap logging logic
    '''
    theLogger = None # class-obj for the used logger

    def __init__(self, appName, clearLogs=False, udpLogging=True):
        self.appName = appName
        self.udpLogging = udpLogging

        if clearLogs:
            self.clearLogs()

        self.parentLogger = self.__getParentLogger()
        self.consoleLoggingStream = None
        self._loggers = [self.parentLogger] # keep track of all loggers

    def close(self):
        for logger in self._loggers:
            for handler in logger.handlers[:]:
                handler.close()
                logger.removeHandler(handler)

        self._loggers = []

    def getLogger(self, name):
        loggerName = '%s.%s' % (self.appName, name) # make this a sublogger of the whole app
        logger = self.__getLoggerWithName(loggerName)
        self._loggers.append(logger)
        return logger

    def __getParentLogger(self):
        logger = self.__getLoggerWithName(self.appName)
        if self.udpLogging:
            handler = UdpHandler()
            handler.setFormatter(self.getFormatter())
            logger.addHandler(handler)

        return logger

    def __getLoggerWithName(self, loggerName):
        logger = logging.getLogger(loggerName)
        logger.setLevel(1) # log all

        logFolder = self.getDefaultSaveDirectory()

        logFile = os.path.join(logFolder, loggerName + ".txt")

        formatter = self.getFormatter()

        rfh = logging.handlers.RotatingFileHandler(logFile, maxBytes=1024*1024*8, backupCount=10)
        rfh.setFormatter(formatter)
        logger.addHandler(rfh)

        return logger

    def getFormatter(self):
        return logging.Formatter('%(asctime)s - %(name)s:%(lineno)d - %(levelname)s - %(message)s')

    def getDefaultSaveDirectory(self):
        return self.getDefaultSaveDirectoryWithName(self.appName)

    def enableConsoleLogging(self, level=1, stream=None):
        if stream is None:
            # evaluate sys.stderr later since pytest may change it
            stream = sys.stderr

        if self.consoleLoggingStream:
            self.disableConsoleLogging()

            # recursive
            return self.enableConsoleLogging(level=level, stream=stream)
        else:
            self.consoleLoggingStream = logging.StreamHandler(stream)
            self.consoleLoggingStream.setFormatter(self.getFormatter())
            self.parentLogger.addHandler(self.consoleLoggingStream)

        self.consoleLoggingStream.setLevel(level)

    def disableConsoleLogging(self):
        if not self.consoleLoggingStream:
            raise RuntimeError("Managed console logging is not active")

        self.parentLogger.removeHandler(self.consoleLoggingStream)
        self.consoleLoggingStream = None

    @classmethod
    def getDefaultSaveDirectoryWithName(cls, appName):
        if os.name == 'nt':
            logFolder = os.path.join(os.path.expandvars("%APPDATA%"), appName)
        else:
            logFolder = os.path.join('/var/log/', appName)

        if not os.path.isdir(logFolder):
            os.makedirs(logFolder)

        return logFolder

    def clearLogs(self):
        shutil.rmtree(self.getDefaultSaveDirectory())

        # recreate empty folder
        self.getDefaultSaveDirectory()

    @classmethod
    def setup(cls, appName, clearLogs=False, udpLogging=True):
        ''' must be called to setup the logger. Passes args to CSMLogger's constructor '''
        if getattr(cls, 'theLogger', None):
            raise RuntimeError("CSMLogger was already setup. It can only be setup once!")

        CSMLogger.theLogger = CSMLogger(appName, clearLogs, udpLogging)
        CSMLogger.theLogger.parentLogger.debug("==== %s is starting ====" % appName)


# the following helper logic only works if the entire application is for one logging folder.
#  not quite sure if it would work with multiple CSMLoggers with different app names

def getLogger(*args, **kwargs):
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")

    return CSMLogger.theLogger.getLogger(*args, **kwargs)

def close():
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")
    retVal = CSMLogger.theLogger.close()
    CSMLogger.theLogger = None
    return retVal

def getCSMLogger():
    return CSMLogger.theLogger

def enableConsoleLogging(*args, **kwargs):
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")

    return CSMLogger.theLogger.enableConsoleLogging(*args, **kwargs)

def disableConsoleLogging(*args, **kwargs):
    if not CSMLogger.theLogger:
        raise RuntimeError("CSMLogger.setup() must be called first!")

    return CSMLogger.theLogger.disableConsoleLogging(*args, **kwargs)

setup = CSMLogger.setup
